import unittest
import cepimose
import datetime

class CepimoseTestCase(unittest.TestCase):

    def setUp(self):
        super().setUp()

    def tearDown(self):
        super().tearDown()

    def test_vaccinations_by_day(self):
        # Test feature one.
        data = cepimose.vaccinations_by_day()
        self.assertTrue(len(data) > 30)

        def assertRow(row, expected_date, expected_first, expected_second):
            self.assertEqual(row.date, expected_date)
            self.assertEqual(row.first_dose, expected_first)
            self.assertEqual(row.second_dose, expected_second)

        assertRow(data[9], datetime.datetime(2021, 1, 5), 15711, 0)
        assertRow(data[22], datetime.datetime(2021, 1, 18), 48710, 315)

    def test_vaccinations_by_age(self):
        # Test feature one.
        data = {row.age_group: row  for row in cepimose.vaccinations_by_age()}

        expected_age_groups = ["0-17", "18-24", "25-29", "30-34", "35-39", "40-44", "45-49", "50-54", "55-59", "60-64", "65-69", "70-74", "75-79", "80-84", "85-89", "90+"]

        self.assertTrue(len(data), len(expected_age_groups))

        for grp in expected_age_groups:
            self.assertGreater(data[grp].count_first, 0)
            self.assertGreater(data[grp].share_first, 0)
            self.assertGreater(data[grp].count_second, 0)
            self.assertGreater(data[grp].share_second, 0)

    def test_vaccinations_by_region(self):
        # Test feature one.
        data = {row.region: row  for row in cepimose.vaccinations_by_region()}

        expected_regions = [
            "Koroška",
            "Zasavska",
            "Goriška",
            "Posavska",
            "Gorenjska",
            "Podravska",
            "Pomurska",
            "Osrednjeslovenska",
            "Jugovzhodna Slovenija",
            "Primorsko-notranjska",
            "Savinjska",
            "Obalno-kraška"
        ]

        print(data.keys())

        self.assertTrue(len(data), len(expected_regions))

        for grp in expected_regions:
            self.assertGreater(data[grp].count_first, 0)
            self.assertGreater(data[grp].share_first, 0)
            self.assertGreater(data[grp].count_second, 0)
            self.assertGreater(data[grp].share_second, 0)

    def test_vaccine_supply_and_usage(self):
        data = cepimose.vaccines_supplied_and_used()
        self.assertTrue(len(data) > 30)

        def assertRow(row, expected_date, expected_supp, expected_used):
            self.assertEqual(row.date, expected_date)
            self.assertEqual(row.supplied, expected_supp)
            self.assertEqual(row.used, expected_used)

        assertRow(data[9], datetime.datetime(2021, 1, 4), 39780, 13248)
        assertRow(data[22], datetime.datetime(2021, 1, 17), 60870, 48798)



import requests
from .data import _source, _headers, _vaccinations_by_day_req, _vaccinations_by_age_req, _vaccines_supplied_and_used_req, _vaccinations_by_region_req
from .parser import _parse_vaccinations_by_age, _parse_vaccinations_by_day, _parse_vaccines_supplued_and_used, _parse_vaccinations_by_region

from .types import VaccinationByAgeRow, VaccinationByDayRow, VaccineSupplyUsage, VaccinationByRegionRow

def _get_data(req, parse_response):
    resp = requests.post(_source, headers=_headers, json=req)
    resp.raise_for_status()
    return parse_response(resp.json())




def vaccinations_by_day() -> 'list[VaccinationByDayRow]':
    return _get_data(_vaccinations_by_day_req, _parse_vaccinations_by_day)

def vaccinations_by_age() -> 'list[VaccinationByAgeRow]':
    return _get_data(_vaccinations_by_age_req, _parse_vaccinations_by_age)

def vaccines_supplied_and_used() -> 'list[VaccineSupplyUsage]':
    return _get_data(_vaccines_supplied_and_used_req, _parse_vaccines_supplued_and_used)

def vaccinations_by_region() -> 'list[VaccinationByRegionRow]':
    return _get_data(_vaccinations_by_region_req, _parse_vaccinations_by_region)


from dataclasses import dataclass
import datetime

@dataclass
class VaccinationByDayRow:
    """Represents on row of vaccinations by day table"""
    date: datetime.datetime
    first_dose: int
    second_dose: int = 0

@dataclass
class VaccinationByAgeRow:
    age_group: str
    count_first: int
    count_second: int
    share_first: float
    share_second: float

@dataclass
class VaccineSupplyUsage:
    date: datetime.datetime
    supplied: int
    used: int

@dataclass
class VaccinationByRegionRow:
    region: str
    count_first: int
    count_second: int
    share_first: float
    share_second: float
    


import json
_source = "https://wabi-west-europe-e-primary-api.analysis.windows.net/public/reports/querydata?synchronous=true"

_headers = {
    "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:87.0) Gecko/20100101 Firefox/87.0",
    "Accept": "application/json, text/plain, */*",
    "ActivityId": "a73e2035-2f0e-290b-319a-c10ebb699c77",
    "RequestId": "25da6f2b-7604-a99a-beef-8c3de4f59f67",
    "X-PowerBI-ResourceKey": "e868280f-1322-4be2-a19a-e9fc2112609f",
    "Content-Type": "application/json;charset=UTF-8",
    "Origin": "https://app.powerbi.com",
    "Connection": "keep-alive",
    "Referer": "https://app.powerbi.com/",
    "Pragma": "no-cache",
    "Cache-Control": "no-cache",
}

_vaccinations_by_day_req = {
	"cancelQueries": [],
	"modelId": 159824,
	"queries": [
		{
			"ApplicationContext": {
				"DatasetId": "7b40529e-a50e-4dd3-8fe8-997894b4cdaa",
				"Sources": [
					{
						"ReportId": "b201281d-b2e7-4470-9f4e-0b3063794c76"
					}
				]
			},
			"CacheKey": "{\"Commands\":[{\"SemanticQueryDataShapeCommand\":{\"Query\":{\"Version\":2,\"From\":[{\"Name\":\"c1\",\"Entity\":\"Calendar\",\"Type\":0},{\"Name\":\"c\",\"Entity\":\"eRCO_podatki\",\"Type\":0}],\"Select\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c1\"}},\"Property\":\"Date\"},\"Name\":\"Calendar.Date\"},{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c\"}},\"Property\":\"Weight running total in Date\"},\"Name\":\"eRCO_podatki.Weight running total in Date\"},{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c\"}},\"Property\":\"Odmerek\"},\"Name\":\"eRCO_podatki.Odmerek\"}],\"Where\":[{\"Condition\":{\"Comparison\":{\"ComparisonKind\":1,\"Left\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c1\"}},\"Property\":\"Date\"}},\"Right\":{\"DateSpan\":{\"Expression\":{\"Literal\":{\"Value\":\"datetime'2020-12-26T01:00:00'\"}},\"TimeUnit\":5}}}}}]},\"Binding\":{\"Primary\":{\"Groupings\":[{\"Projections\":[0,1]}]},\"Secondary\":{\"Groupings\":[{\"Projections\":[2]}]},\"DataReduction\":{\"DataVolume\":4,\"Intersection\":{\"BinnedLineSample\":{}}},\"Version\":1}}}]}",
			"Query": {
				"Commands": [
					{
						"SemanticQueryDataShapeCommand": {
							"Binding": {
								"DataReduction": {
									"DataVolume": 4,
									"Intersection": {
										"BinnedLineSample": {}
									}
								},
								"Primary": {
									"Groupings": [
										{
											"Projections": [
												0,
												1
											]
										}
									]
								},
								"Secondary": {
									"Groupings": [
										{
											"Projections": [
												2
											]
										}
									]
								},
								"Version": 1
							},
							"Query": {
								"From": [
									{
										"Entity": "Calendar",
										"Name": "c1",
										"Type": 0
									},
									{
										"Entity": "eRCO_podatki",
										"Name": "c",
										"Type": 0
									}
								],
								"Select": [
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "c1"
												}
											},
											"Property": "Date"
										},
										"Name": "Calendar.Date"
									},
									{
										"Measure": {
											"Expression": {
												"SourceRef": {
													"Source": "c"
												}
											},
											"Property": "Weight running total in Date"
										},
										"Name": "eRCO_podatki.Weight running total in Date"
									},
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "c"
												}
											},
											"Property": "Odmerek"
										},
										"Name": "eRCO_podatki.Odmerek"
									}
								],
								"Version": 2,
								"Where": [
									{
										"Condition": {
											"Comparison": {
												"ComparisonKind": 1,
												"Left": {
													"Column": {
														"Expression": {
															"SourceRef": {
																"Source": "c1"
															}
														},
														"Property": "Date"
													}
												},
												"Right": {
													"DateSpan": {
														"Expression": {
															"Literal": {
																"Value": "datetime'2020-12-26T01:00:00'"
															}
														},
														"TimeUnit": 5
													}
												}
											}
										}
									}
								]
							}
						}
					}
				]
			},
			"QueryId": ""
		}
	],
	"version": "1.0.0"
}

_vaccinations_by_age_req = {
	"cancelQueries": [],
	"modelId": 159824,
	"queries": [
		{
			"ApplicationContext": {
				"DatasetId": "7b40529e-a50e-4dd3-8fe8-997894b4cdaa",
				"Sources": [
					{
						"ReportId": "b201281d-b2e7-4470-9f4e-0b3063794c76"
					}
				]
			},
			"CacheKey": "{\"Commands\":[{\"SemanticQueryDataShapeCommand\":{\"Query\":{\"Version\":2,\"From\":[{\"Name\":\"e\",\"Entity\":\"eRCO_podatki\",\"Type\":0},{\"Name\":\"s\",\"Entity\":\"SURS_starost\",\"Type\":0},{\"Name\":\"c\",\"Entity\":\"Calendar\",\"Type\":0}],\"Select\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"s\"}},\"Property\":\"Starostni razred\"},\"Name\":\"SURS_starost.Starostni razred\"},{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Delež_starost\"},\"Name\":\"eRCO_podatki.Delež_starost\"},{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Odmerek\"},\"Name\":\"eRCO_podatki.Odmerek\"},{\"Aggregation\":{\"Expression\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Weight\"}},\"Function\":0},\"Name\":\"Sum(eRCO_podatki.Weight)\"}],\"Where\":[{\"Condition\":{\"Not\":{\"Expression\":{\"In\":{\"Expressions\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"CepivoIme\"}}],\"Values\":[[{\"Literal\":{\"Value\":\"null\"}}]]}}}}},{\"Condition\":{\"Comparison\":{\"ComparisonKind\":1,\"Left\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c\"}},\"Property\":\"Date\"}},\"Right\":{\"DateSpan\":{\"Expression\":{\"Literal\":{\"Value\":\"datetime'2020-12-26T01:00:00'\"}},\"TimeUnit\":5}}}}}],\"OrderBy\":[{\"Direction\":1,\"Expression\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"s\"}},\"Property\":\"Starostni razred\"}}}]},\"Binding\":{\"Primary\":{\"Groupings\":[{\"Projections\":[0,1,3]}]},\"Secondary\":{\"Groupings\":[{\"Projections\":[2]}]},\"DataReduction\":{\"DataVolume\":4,\"Primary\":{\"Window\":{\"Count\":200}},\"Secondary\":{\"Top\":{\"Count\":60}}},\"SuppressedJoinPredicates\":[3],\"Version\":1}}}]}",
			"Query": {
				"Commands": [
					{
						"SemanticQueryDataShapeCommand": {
							"Binding": {
								"DataReduction": {
									"DataVolume": 4,
									"Primary": {
										"Window": {
											"Count": 200
										}
									},
									"Secondary": {
										"Top": {
											"Count": 60
										}
									}
								},
								"Primary": {
									"Groupings": [
										{
											"Projections": [
												0,
												1,
												3
											]
										}
									]
								},
								"Secondary": {
									"Groupings": [
										{
											"Projections": [
												2
											]
										}
									]
								},
								"SuppressedJoinPredicates": [
									3
								],
								"Version": 1
							},
							"Query": {
								"From": [
									{
										"Entity": "eRCO_podatki",
										"Name": "e",
										"Type": 0
									},
									{
										"Entity": "SURS_starost",
										"Name": "s",
										"Type": 0
									},
									{
										"Entity": "Calendar",
										"Name": "c",
										"Type": 0
									}
								],
								"OrderBy": [
									{
										"Direction": 1,
										"Expression": {
											"Column": {
												"Expression": {
													"SourceRef": {
														"Source": "s"
													}
												},
												"Property": "Starostni razred"
											}
										}
									}
								],
								"Select": [
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "s"
												}
											},
											"Property": "Starostni razred"
										},
										"Name": "SURS_starost.Starostni razred"
									},
									{
										"Measure": {
											"Expression": {
												"SourceRef": {
													"Source": "e"
												}
											},
											"Property": "Delež_starost"
										},
										"Name": "eRCO_podatki.Delež_starost"
									},
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "e"
												}
											},
											"Property": "Odmerek"
										},
										"Name": "eRCO_podatki.Odmerek"
									},
									{
										"Aggregation": {
											"Expression": {
												"Column": {
													"Expression": {
														"SourceRef": {
															"Source": "e"
														}
													},
													"Property": "Weight"
												}
											},
											"Function": 0
										},
										"Name": "Sum(eRCO_podatki.Weight)"
									}
								],
								"Version": 2,
								"Where": [
									{
										"Condition": {
											"Not": {
												"Expression": {
													"In": {
														"Expressions": [
															{
																"Column": {
																	"Expression": {
																		"SourceRef": {
																			"Source": "e"
																		}
																	},
																	"Property": "CepivoIme"
																}
															}
														],
														"Values": [
															[
																{
																	"Literal": {
																		"Value": "null"
																	}
																}
															]
														]
													}
												}
											}
										}
									},
									{
										"Condition": {
											"Comparison": {
												"ComparisonKind": 1,
												"Left": {
													"Column": {
														"Expression": {
															"SourceRef": {
																"Source": "c"
															}
														},
														"Property": "Date"
													}
												},
												"Right": {
													"DateSpan": {
														"Expression": {
															"Literal": {
																"Value": "datetime'2020-12-26T01:00:00'"
															}
														},
														"TimeUnit": 5
													}
												}
											}
										}
									}
								]
							}
						}
					}
				]
			},
			"QueryId": ""
		}
	],
	"version": "1.0.0"
}

_vaccines_supplied_and_used_req = {
	"cancelQueries": [],
	"modelId": 159824,
	"queries": [
		{
			"ApplicationContext": {
				"DatasetId": "7b40529e-a50e-4dd3-8fe8-997894b4cdaa",
				"Sources": [
					{
						"ReportId": "b201281d-b2e7-4470-9f4e-0b3063794c76"
					}
				]
			},
			"CacheKey": "{\"Commands\":[{\"SemanticQueryDataShapeCommand\":{\"Query\":{\"Version\":2,\"From\":[{\"Name\":\"c1\",\"Entity\":\"Calendar\",\"Type\":0},{\"Name\":\"c\",\"Entity\":\"eRCO_podatki\",\"Type\":0},{\"Name\":\"n\",\"Entity\":\"NIJZ_Odmerki\",\"Type\":0}],\"Select\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c1\"}},\"Property\":\"Date\"},\"Name\":\"Calendar.Date\"},{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c\"}},\"Property\":\"Kumulativno skupaj cepljenih\"},\"Name\":\"eRCO_podatki.Kumulativno skupaj cepljenih\"},{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"n\"}},\"Property\":\"Tekoča vsota za mero odmerki* v polju Date\"},\"Name\":\"NIJZ_Odmerki.Tekoča vsota za mero odmerki* v polju Date\"}],\"Where\":[{\"Condition\":{\"Comparison\":{\"ComparisonKind\":2,\"Left\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c1\"}},\"Property\":\"Date\"}},\"Right\":{\"DateSpan\":{\"Expression\":{\"Literal\":{\"Value\":\"datetime'2020-12-26T00:00:00'\"}},\"TimeUnit\":5}}}}}]},\"Binding\":{\"Primary\":{\"Groupings\":[{\"Projections\":[0,1,2]}]},\"DataReduction\":{\"DataVolume\":4,\"Primary\":{\"BinnedLineSample\":{}}},\"Version\":1}}}]}",
			"Query": {
				"Commands": [
					{
						"SemanticQueryDataShapeCommand": {
							"Binding": {
								"DataReduction": {
									"DataVolume": 4,
									"Primary": {
										"BinnedLineSample": {}
									}
								},
								"Primary": {
									"Groupings": [
										{
											"Projections": [
												0,
												1,
												2
											]
										}
									]
								},
								"Version": 1
							},
							"Query": {
								"From": [
									{
										"Entity": "Calendar",
										"Name": "c1",
										"Type": 0
									},
									{
										"Entity": "eRCO_podatki",
										"Name": "c",
										"Type": 0
									},
									{
										"Entity": "NIJZ_Odmerki",
										"Name": "n",
										"Type": 0
									}
								],
								"Select": [
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "c1"
												}
											},
											"Property": "Date"
										},
										"Name": "Calendar.Date"
									},
									{
										"Measure": {
											"Expression": {
												"SourceRef": {
													"Source": "c"
												}
											},
											"Property": "Kumulativno skupaj cepljenih"
										},
										"Name": "eRCO_podatki.Kumulativno skupaj cepljenih"
									},
									{
										"Measure": {
											"Expression": {
												"SourceRef": {
													"Source": "n"
												}
											},
											"Property": "Tekoča vsota za mero odmerki* v polju Date"
										},
										"Name": "NIJZ_Odmerki.Tekoča vsota za mero odmerki* v polju Date"
									}
								],
								"Version": 2,
								"Where": [
									{
										"Condition": {
											"Comparison": {
												"ComparisonKind": 2,
												"Left": {
													"Column": {
														"Expression": {
															"SourceRef": {
																"Source": "c1"
															}
														},
														"Property": "Date"
													}
												},
												"Right": {
													"DateSpan": {
														"Expression": {
															"Literal": {
																"Value": "datetime'2020-12-26T00:00:00'"
															}
														},
														"TimeUnit": 5
													}
												}
											}
										}
									}
								]
							}
						}
					}
				]
			},
			"QueryId": ""
		}
	],
	"version": "1.0.0"
}

_vaccinations_by_region_req = {
	"cancelQueries": [],
	"modelId": 159824,
	"queries": [
		{
			"ApplicationContext": {
				"DatasetId": "7b40529e-a50e-4dd3-8fe8-997894b4cdaa",
				"Sources": [
					{
						"ReportId": "b201281d-b2e7-4470-9f4e-0b3063794c76"
					}
				]
			},
			"CacheKey": "{\"Commands\":[{\"SemanticQueryDataShapeCommand\":{\"Query\":{\"Version\":2,\"From\":[{\"Name\":\"e\",\"Entity\":\"eRCO_podatki\",\"Type\":0},{\"Name\":\"s1\",\"Entity\":\"Sifrant_regija\",\"Type\":0},{\"Name\":\"c\",\"Entity\":\"Calendar\",\"Type\":0}],\"Select\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"s1\"}},\"Property\":\"Regija\"},\"Name\":\"Sifrant_regija.Regija\"},{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Odmerek\"},\"Name\":\"eRCO_podatki.Odmerek\"},{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Delež_regija\"},\"Name\":\"eRCO_podatki.Delež_regija\"},{\"Aggregation\":{\"Expression\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Weight\"}},\"Function\":0},\"Name\":\"Sum(eRCO_podatki.Weight)\"}],\"Where\":[{\"Condition\":{\"Not\":{\"Expression\":{\"In\":{\"Expressions\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"CepivoIme\"}}],\"Values\":[[{\"Literal\":{\"Value\":\"null\"}}]]}}}}},{\"Condition\":{\"Not\":{\"Expression\":{\"In\":{\"Expressions\":[{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"s1\"}},\"Property\":\"Regija\"}}],\"Values\":[[{\"Literal\":{\"Value\":\"null\"}}],[{\"Literal\":{\"Value\":\"'Celotna Slovenija'\"}}],[{\"Literal\":{\"Value\":\"'TUJINA'\"}}]]}}}}},{\"Condition\":{\"Comparison\":{\"ComparisonKind\":1,\"Left\":{\"Column\":{\"Expression\":{\"SourceRef\":{\"Source\":\"c\"}},\"Property\":\"Date\"}},\"Right\":{\"DateSpan\":{\"Expression\":{\"Literal\":{\"Value\":\"datetime'2020-12-26T01:00:00'\"}},\"TimeUnit\":5}}}}}],\"OrderBy\":[{\"Direction\":2,\"Expression\":{\"Measure\":{\"Expression\":{\"SourceRef\":{\"Source\":\"e\"}},\"Property\":\"Delež_regija\"}}}]},\"Binding\":{\"Primary\":{\"Groupings\":[{\"Projections\":[0,2,3]}]},\"Secondary\":{\"Groupings\":[{\"Projections\":[1]}]},\"DataReduction\":{\"DataVolume\":4,\"Primary\":{\"Window\":{\"Count\":200}},\"Secondary\":{\"Top\":{\"Count\":60}}},\"SuppressedJoinPredicates\":[3],\"Version\":1}}}]}",
			"Query": {
				"Commands": [
					{
						"SemanticQueryDataShapeCommand": {
							"Binding": {
								"DataReduction": {
									"DataVolume": 4,
									"Primary": {
										"Window": {
											"Count": 200
										}
									},
									"Secondary": {
										"Top": {
											"Count": 60
										}
									}
								},
								"Primary": {
									"Groupings": [
										{
											"Projections": [
												0,
												2,
												3
											]
										}
									]
								},
								"Secondary": {
									"Groupings": [
										{
											"Projections": [
												1
											]
										}
									]
								},
								"SuppressedJoinPredicates": [
									3
								],
								"Version": 1
							},
							"Query": {
								"From": [
									{
										"Entity": "eRCO_podatki",
										"Name": "e",
										"Type": 0
									},
									{
										"Entity": "Sifrant_regija",
										"Name": "s1",
										"Type": 0
									},
									{
										"Entity": "Calendar",
										"Name": "c",
										"Type": 0
									}
								],
								"OrderBy": [
									{
										"Direction": 2,
										"Expression": {
											"Measure": {
												"Expression": {
													"SourceRef": {
														"Source": "e"
													}
												},
												"Property": "Delež_regija"
											}
										}
									}
								],
								"Select": [
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "s1"
												}
											},
											"Property": "Regija"
										},
										"Name": "Sifrant_regija.Regija"
									},
									{
										"Column": {
											"Expression": {
												"SourceRef": {
													"Source": "e"
												}
											},
											"Property": "Odmerek"
										},
										"Name": "eRCO_podatki.Odmerek"
									},
									{
										"Measure": {
											"Expression": {
												"SourceRef": {
													"Source": "e"
												}
											},
											"Property": "Delež_regija"
										},
										"Name": "eRCO_podatki.Delež_regija"
									},
									{
										"Aggregation": {
											"Expression": {
												"Column": {
													"Expression": {
														"SourceRef": {
															"Source": "e"
														}
													},
													"Property": "Weight"
												}
											},
											"Function": 0
										},
										"Name": "Sum(eRCO_podatki.Weight)"
									}
								],
								"Version": 2,
								"Where": [
									{
										"Condition": {
											"Not": {
												"Expression": {
													"In": {
														"Expressions": [
															{
																"Column": {
																	"Expression": {
																		"SourceRef": {
																			"Source": "e"
																		}
																	},
																	"Property": "CepivoIme"
																}
															}
														],
														"Values": [
															[
																{
																	"Literal": {
																		"Value": "null"
																	}
																}
															]
														]
													}
												}
											}
										}
									},
									{
										"Condition": {
											"Not": {
												"Expression": {
													"In": {
														"Expressions": [
															{
																"Column": {
																	"Expression": {
																		"SourceRef": {
																			"Source": "s1"
																		}
																	},
																	"Property": "Regija"
																}
															}
														],
														"Values": [
															[
																{
																	"Literal": {
																		"Value": "null"
																	}
																}
															],
															[
																{
																	"Literal": {
																		"Value": "'Celotna Slovenija'"
																	}
																}
															],
															[
																{
																	"Literal": {
																		"Value": "'TUJINA'"
																	}
																}
															]
														]
													}
												}
											}
										}
									},
									{
										"Condition": {
											"Comparison": {
												"ComparisonKind": 1,
												"Left": {
													"Column": {
														"Expression": {
															"SourceRef": {
																"Source": "c"
															}
														},
														"Property": "Date"
													}
												},
												"Right": {
													"DateSpan": {
														"Expression": {
															"Literal": {
																"Value": "datetime'2020-12-26T01:00:00'"
															}
														},
														"TimeUnit": 5
													}
												}
											}
										}
									}
								]
							}
						}
					}
				]
			},
			"QueryId": ""
		}
	],
	"version": "1.0.0"
}


import datetime

from .types import VaccinationByDayRow, VaccinationByAgeRow, VaccineSupplyUsage, VaccinationByRegionRow

def parse_date(raw):
    return datetime.datetime.utcfromtimestamp(float(raw)/1000.0)

def _parse_vaccinations_by_day(data) -> 'list[VaccinationByDayRow]':
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        date = parse_date(element["G0"])
        people_vaccinated = element["X"][0]["M0"]
        people_fully_vaccinated = element["X"][1]["M0"] if len(element["X"]) > 1 else 0

        parsed_data.append(VaccinationByDayRow(
            date=date,
            first_dose=people_vaccinated,
            second_dose=people_fully_vaccinated
        ))

    return parsed_data

def _parse_vaccinations_by_age(data) -> 'list[VaccinationByAgeRow]':
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        age_group = str(element["G0"])
        count_first = int(element["X"][0]["C"][1])
        count_second = int(element["X"][1]["C"][1])
        share_first = float(element["X"][0]["C"][0])/100.0
        share_second = float(element["X"][1]["C"][0])/100.0

        parsed_data.append(VaccinationByAgeRow(
            age_group=age_group,
            count_first=count_first,
            count_second=count_second,
            share_first=share_first,
            share_second=share_second
        ))

    return parsed_data


def _parse_vaccines_supplued_and_used(data) -> 'list[VaccineSupplyUsage]':
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        
        date = parse_date(element["C"][0])

        if "Ø" in element:
            supplied = int(element["C"][1]) if len(element["C"]) > 1 else 0
            used = 0
        else:
            used = int(element["C"][1]) if len(element["C"]) > 1 else parsed_data[-1].used
            supplied = int(element["C"][2]) if len(element["C"]) > 2 else parsed_data[-1].supplied

        row = VaccineSupplyUsage(
            date=date,
            supplied=supplied,
            used=used,
        )
        parsed_data.append(row)

    return parsed_data

def _parse_vaccinations_by_region(data) -> 'list[VaccinationByRegionRow]':
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        region = str(element["G0"])
        count_first = int(element["X"][0]["C"][1])
        count_second = int(element["X"][1]["C"][1])
        share_first = float(element["X"][0]["C"][0])/100.0
        share_second = float(element["X"][1]["C"][0])/100.0

        parsed_data.append(VaccinationByRegionRow(
            region=region,
            count_first=count_first,
            count_second=count_second,
            share_first=share_first,
            share_second=share_second
        ))

    return parsed_data